import { SymbolInformation, TextDocumentIdentifier } from 'vscode-languageserver-types';
export declare class DockerSymbols {
    private createSymbolInformation;
    parseSymbolInformation(textDocument: TextDocumentIdentifier, content: string): SymbolInformation[];
}
