module.exports={A:{A:{"1":"A B","2":"K D E F aC"},B:{"1":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I","2":"C L M G N O P"},C:{"1":"0 1 2 3 4 5 6 7 8 9 RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC","2":"bC CC dC eC","132":"J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC","2":"J","16":"EB K D E v w x y z","132":"F A B C L M G N O P FB u"},E:{"1":"C L M G 6B 7B kC lC mC LC MC 8B nC 9B NC OC PC QC RC oC AC SC TC UC VC WC XC BC pC","2":"J EB fC JC gC","132":"K D E F A B hC iC jC KC"},F:{"1":"G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t","2":"F B C qC rC sC tC 6B YC uC 7B"},G:{"2":"xC yC","132":"E zC 0C 1C 2C 3C 4C 5C 6C 7C 8C 9C AD BD CD DD ED LC MC 8B FD 9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC","514":"JC vC ZC wC"},H:{"2":"HD"},I:{"2":"ID JD KD","260":"CC J LD ZC","514":"I MD ND"},J:{"132":"A","260":"D"},K:{"2":"A B C 6B YC 7B","514":"H"},L:{"260":"I"},M:{"2":"5B"},N:{"514":"A","1028":"B"},O:{"2":"8B"},P:{"260":"J u v w x y z OD PD QD RD SD KC TD UD VD WD XD 9B AC BC YD"},Q:{"260":"ZD"},R:{"260":"aD"},S:{"1":"bD cD"}},B:1,C:"accept attribute for file input",D:true};
