import { Position, DocumentHighlight } from 'vscode-languageserver-types';
export declare class DockerHighlight {
    computeHighlightRanges(content: string, position: Position): DocumentHighlight[];
}
