'use strict'

const Async = require('./lib/Async')
const Sync = require('./lib/Sync')
const unwrapSync = require('./lib/unwrapSync')

exports.sync = () => new Sync()
exports.async = () => new Async()
exports.unwrapSync = unwrapSync
