module.exports={A:{A:{"2":"K D E F A B aC"},B:{"2":"C L M G N O P","2052":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I"},C:{"2":"bC CC J EB dC eC","1028":"0 1 2 3 4 5 6 7 8 9 QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC","1060":"K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB"},D:{"2":"J EB K D E F A B C L M G N O P FB u v w x y z","226":"GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB","2052":"0 1 2 3 4 5 6 7 8 9 lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC"},E:{"2":"J EB K D fC JC gC hC","772":"L M G 7B kC lC mC LC MC 8B nC 9B NC OC PC QC RC oC AC SC TC UC VC WC XC BC pC","804":"E F A B C jC KC 6B","1316":"iC"},F:{"2":"F B C G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB qC rC sC tC 6B YC uC 7B","226":"PB QB RB SB TB UB VB WB XB","2052":"YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t"},G:{"2":"JC vC ZC wC xC yC","292":"E zC 0C 1C 2C 3C 4C 5C 6C 7C 8C 9C AD BD CD DD ED LC MC 8B FD 9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC"},H:{"2":"HD"},I:{"1":"I","2":"CC J ID JD KD LD ZC MD ND"},J:{"2":"D A"},K:{"2":"A B C 6B YC 7B","2052":"H"},L:{"2052":"I"},M:{"1028":"5B"},N:{"2":"A B"},O:{"2052":"8B"},P:{"2":"J OD PD","2052":"u v w x y z QD RD SD KC TD UD VD WD XD 9B AC BC YD"},Q:{"2052":"ZD"},R:{"2052":"aD"},S:{"1028":"bD cD"}},B:4,C:"text-decoration styling",D:true};
