import { CompletionItem, MarkupKind } from 'vscode-languageserver-types';
export declare class DockerCompletion {
    private dockerMarkdown;
    private dockerPlainText;
    resolveCompletionItem(item: CompletionItem, documentationFormat?: MarkupKind[]): CompletionItem;
}
