import { SemanticTokens } from 'vscode-languageserver-types';
export declare class TokensLegend {
    private static tokenTypes;
    private static tokenModifiers;
    static init(): void;
    static getTokenType(type: string): number;
    static getTokenModifiers(modifiers: string[]): number;
}
export declare class DockerSemanticTokens {
    private currentRange;
    private content;
    private document;
    private dockerfile;
    private tokens;
    private quote;
    private escapedQuote;
    private readonly escapeCharacter;
    constructor(content: string);
    computeSemanticTokens(): SemanticTokens;
    private createTokensForInstruction;
    private createArgumentTokens;
    private handleLineChange;
    private createEscapeToken;
    private createVariableToken;
    private createToken;
}
