module.exports={A:{A:{"2":"K D E F A B aC"},B:{"2":"C L M","33":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I","161":"G N O P"},C:{"2":"bC CC J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB dC eC","161":"0 1 2 3 4 5 6 7 8 9 dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC","450":"cB"},D:{"33":"0 1 2 3 4 5 6 7 8 9 J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC"},E:{"33":"J EB K D E F A B C L M G fC JC gC hC iC jC KC 6B 7B kC lC mC LC MC 8B nC 9B NC OC PC QC RC oC AC SC TC UC VC WC XC BC pC"},F:{"2":"F B C qC rC sC tC 6B YC uC 7B","33":"G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t"},G:{"33":"E vC ZC wC xC yC zC 0C 1C 2C 3C 4C 5C 6C 7C 8C 9C AD BD CD DD ED LC MC 8B FD 9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC","36":"JC"},H:{"2":"HD"},I:{"2":"CC","33":"J I ID JD KD LD ZC MD ND"},J:{"33":"D A"},K:{"2":"A B C 6B YC 7B","33":"H"},L:{"33":"I"},M:{"161":"5B"},N:{"2":"A B"},O:{"33":"8B"},P:{"33":"J u v w x y z OD PD QD RD SD KC TD UD VD WD XD 9B AC BC YD"},Q:{"33":"ZD"},R:{"33":"aD"},S:{"161":"bD cD"}},B:7,C:"CSS text-stroke and text-fill",D:true};
