module.exports={A:{A:{"388":"A B","900":"K D E F aC"},B:{"388":"C L M G N O P","641":"0 1 2 3 4 5 6 7 8 9 r s t AB BB CB DB I","900":"Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q"},C:{"772":"0 1 2 3 4 5 6 7 8 9 rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC","900":"bC CC J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB dC eC"},D:{"641":"0 1 2 3 4 5 6 7 8 9 r s t AB BB CB DB I 5B GC HC IC","900":"J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q"},E:{"772":"A","900":"J EB K D E F B C L M G fC JC gC hC iC jC KC 6B 7B kC lC mC LC MC 8B nC 9B NC OC PC QC RC oC AC SC TC UC VC WC XC BC pC"},F:{"16":"F qC","129":"B C rC sC tC 6B YC uC 7B","641":"d e f g h i j k l m n o p q r s t","900":"G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c"},G:{"900":"E JC vC ZC wC xC yC zC 0C 1C 2C 3C 4C 5C 6C 7C 8C 9C AD BD CD DD ED LC MC 8B FD 9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC"},H:{"129":"HD"},I:{"641":"I","900":"CC J ID JD KD LD ZC MD ND"},J:{"900":"D A"},K:{"129":"A B C 6B YC 7B","641":"H"},L:{"900":"I"},M:{"772":"5B"},N:{"388":"A B"},O:{"900":"8B"},P:{"641":"v w x y z","900":"J u OD PD QD RD SD KC TD UD VD WD XD 9B AC BC YD"},Q:{"900":"ZD"},R:{"900":"aD"},S:{"772":"cD","900":"bD"}},B:2,C:"CSS page-break properties",D:true};
