module.exports={A:{A:{"1":"B","4":"K D E F A aC"},B:{"1":"C L M G N","129":"0 1 2 3 4 5 6 7 8 9 O P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I"},C:{"1":"K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB","4":"bC CC J EB dC eC","129":"0 1 2 3 4 5 6 7 8 9 fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC"},D:{"1":"ZB aB bB cB dB eB fB gB hB iB","4":"J EB K","129":"0 1 2 3 4 5 6 7 8 9 D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC"},E:{"4":"J EB fC JC","129":"K D E F A B C L M G gC hC iC jC KC 6B 7B kC lC mC LC MC 8B nC 9B NC OC PC QC RC oC AC SC TC UC VC WC XC BC pC"},F:{"1":"C MB NB OB PB QB RB SB TB UB VB 6B YC uC 7B","4":"F B qC rC sC tC","129":"G N O P FB u v w x y z GB HB IB JB KB LB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t"},G:{"4":"JC vC ZC","129":"E wC xC yC zC 0C 1C 2C 3C 4C 5C 6C 7C 8C 9C AD BD CD DD ED LC MC 8B FD 9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC"},H:{"4":"HD"},I:{"4":"ID JD KD","129":"CC J I LD ZC MD ND"},J:{"129":"D A"},K:{"1":"C 6B YC 7B","4":"A B","129":"H"},L:{"129":"I"},M:{"129":"5B"},N:{"1":"B","4":"A"},O:{"129":"8B"},P:{"129":"J u v w x y z OD PD QD RD SD KC TD UD VD WD XD 9B AC BC YD"},Q:{"129":"ZD"},R:{"129":"aD"},S:{"1":"bD","129":"cD"}},B:1,C:"dataset & data-* attributes",D:true};
