import { Range, Position, TextEdit, TextDocumentIdentifier } from 'vscode-languageserver-types';
export declare class DockerRename {
    prepareRename(content: string, position: Position): Range | null;
    rename(textDocument: TextDocumentIdentifier, content: string, position: Position, newName: string): TextEdit[];
}
