module.exports={A:{A:{"644":"K D E F aC","772":"A B"},B:{"1":"0 1 2 3 4 5 6 7 8 9 P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I","260":"C L M G N O"},C:{"1":"0 1 2 3 4 5 6 7 8 9 J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC dC eC","8":"bC CC"},D:{"1":"0 1 2 3 4 5 6 7 8 9 J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC"},E:{"1":"J EB K D E F A B C L M G fC JC gC hC iC jC KC 6B 7B kC lC mC LC MC 8B nC 9B NC OC PC QC RC oC AC SC TC UC VC WC XC BC pC"},F:{"1":"C G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t 7B","8":"F B qC rC sC tC 6B YC uC"},G:{"1":"ED LC MC 8B FD 9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC","2":"E JC vC ZC wC xC yC zC 0C 1C 2C 3C 4C 5C 6C 7C 8C 9C AD BD CD DD"},H:{"2":"HD"},I:{"2":"CC J ID JD KD LD ZC MD ND","1025":"I"},J:{"2":"D A"},K:{"1":"7B","8":"A B C 6B YC","1025":"H"},L:{"1025":"I"},M:{"2":"5B"},N:{"1":"A B"},O:{"1025":"8B"},P:{"2":"J u v w x y z OD PD QD RD SD KC TD UD VD WD XD 9B AC BC YD"},Q:{"1":"ZD"},R:{"2":"aD"},S:{"2":"bD cD"}},B:1,C:"Drag and Drop",D:true};
