module.exports={A:{A:{"2":"K D E aC","2561":"A B","2692":"F"},B:{"1":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I","2561":"C L M G N O P"},C:{"1":"0 1 2 3 4 5 6 7 8 9 dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC","16":"bC","1537":"J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB eC","1796":"CC dC"},D:{"1":"0 1 2 3 4 5 6 7 8 9 sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC","16":"J EB K D E F A B C L M","1025":"PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB","1537":"G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB"},E:{"1":"M G kC lC mC LC MC 8B nC 9B NC OC PC QC RC oC AC SC TC UC VC WC XC BC pC","16":"J EB K fC JC","1025":"D E F A B C hC iC jC KC 6B","1537":"gC","4097":"L 7B"},F:{"1":"gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t 7B","16":"F B C qC rC sC tC 6B YC","260":"uC","1025":"w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB","1537":"G N O P FB u v"},G:{"1":"9C AD BD CD DD ED LC MC 8B FD 9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC","16":"JC vC ZC","1025":"E zC 0C 1C 2C 3C 4C 5C 6C","1537":"wC xC yC","4097":"7C 8C"},H:{"2":"HD"},I:{"16":"ID JD","1025":"I ND","1537":"CC J KD LD ZC MD"},J:{"1025":"A","1537":"D"},K:{"1":"A B C H 6B YC 7B"},L:{"1":"I"},M:{"1":"5B"},N:{"2561":"A B"},O:{"1":"8B"},P:{"1025":"J u v w x y z OD PD QD RD SD KC TD UD VD WD XD 9B AC BC YD"},Q:{"1":"ZD"},R:{"1":"aD"},S:{"1":"cD","1537":"bD"}},B:1,C:"input event",D:true};
