import { Hover } from 'vscode-languageserver-types';
export declare class MarkdownDocumentation {
    private dockerMessages;
    private markdowns;
    constructor();
    private formatMessage;
    /**
     * Retrieves the Markdown documentation for the given word.
     *
     * @param word the Dockerfile keyword or directive, must not be null
     */
    getMarkdown(word: string): Hover;
}
