module.exports={A:{A:{"2":"K D E F aC","129":"A B"},B:{"1":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I","129":"C L","1025":"M G N O P"},C:{"2":"bC CC J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB dC eC","513":"0 1 2 3 4 5 6 7 8 9 JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC"},D:{"1":"0 1 2 3 4 5 6 7 8 9 K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC","2":"J EB"},E:{"1":"EB K D E F A B C L M G gC hC iC jC KC 6B 7B kC lC mC LC MC 8B nC 9B NC OC PC QC RC oC AC SC TC UC VC WC XC BC pC","2":"J fC JC"},F:{"1":"F B C G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t qC rC sC tC 6B YC uC 7B"},G:{"388":"E JC vC ZC wC xC yC zC 0C 1C 2C 3C 4C 5C 6C 7C 8C 9C AD BD CD DD ED LC MC 8B FD 9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC"},H:{"2":"HD"},I:{"2":"CC ID JD KD","388":"J I LD ZC MD ND"},J:{"2":"D","388":"A"},K:{"1":"A B C 6B YC 7B","388":"H"},L:{"388":"I"},M:{"641":"5B"},N:{"388":"A B"},O:{"388":"8B"},P:{"388":"J u v w x y z OD PD QD RD SD KC TD UD VD WD XD 9B AC BC YD"},Q:{"388":"ZD"},R:{"388":"aD"},S:{"513":"bD cD"}},B:1,C:"Number input type",D:true};
