module.exports={A:{A:{"2":"K D E F A B aC"},B:{"1":"0 1 2 3 4 5 6 7 8 9 L M G N O P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I","2":"C"},C:{"1":"0 1 2 3 4 5 6 7 8 9 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC","16":"bC","33":"CC J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B dC eC"},D:{"1":"0 1 2 3 4 5 6 7 8 9 QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC","16":"J EB K D E F A B C L M","132":"G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB"},E:{"1":"F A B C L M G jC KC 6B 7B kC lC mC LC MC 8B nC 9B NC OC PC QC RC oC AC SC TC UC VC WC XC BC pC","16":"fC JC","132":"J EB K D E gC hC iC"},F:{"1":"x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t","16":"F B qC rC sC tC 6B","132":"C G N O P FB u v w YC uC 7B"},G:{"1":"0C 1C 2C 3C 4C 5C 6C 7C 8C 9C AD BD CD DD ED LC MC 8B FD 9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC","16":"JC vC","132":"E ZC wC xC yC zC"},H:{"2":"HD"},I:{"1":"I","16":"ID JD","132":"CC J KD LD ZC MD ND"},J:{"1":"A","132":"D"},K:{"1":"H","2":"A B 6B","132":"C YC 7B"},L:{"1":"I"},M:{"1":"5B"},N:{"2":"A B"},O:{"1":"8B"},P:{"1":"J u v w x y z OD PD QD RD SD KC TD UD VD WD XD 9B AC BC YD"},Q:{"1":"ZD"},R:{"1":"aD"},S:{"1":"cD","33":"bD"}},B:1,C:"CSS :read-only and :read-write selectors",D:true};
