module.exports={A:{A:{"2436":"K D E F A B aC"},B:{"260":"O P","2436":"C L M G N","8196":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I"},C:{"2":"bC CC J EB K D E F A B C L M G N O P FB u v dC eC","772":"w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB","4100":"0 1 2 3 4 5 6 7 8 9 VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC"},D:{"2":"J EB K D E F A B C","2564":"L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB","8196":"0 1 2 3 4 5 6 7 8 9 mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC","10244":"XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB"},E:{"1":"C L M G 7B kC lC mC LC MC 8B nC 9B NC OC PC QC RC oC AC SC TC UC VC WC XC BC pC","16":"fC JC","2308":"A B KC 6B","2820":"J EB K D E F gC hC iC jC"},F:{"2":"F B qC rC sC tC 6B YC uC","16":"C","516":"7B","2564":"G N O P FB u v w x y z GB HB IB JB","8196":"ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t","10244":"KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB"},G:{"1":"6C 7C 8C 9C AD BD CD DD ED LC MC 8B FD 9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC","2":"JC vC ZC","2820":"E wC xC yC zC 0C 1C 2C 3C 4C 5C"},H:{"2":"HD"},I:{"2":"CC J ID JD KD LD ZC","260":"I","2308":"MD ND"},J:{"2":"D","2308":"A"},K:{"2":"A B C 6B YC","16":"7B","8196":"H"},L:{"8196":"I"},M:{"1028":"5B"},N:{"2":"A B"},O:{"8196":"8B"},P:{"2052":"OD PD","2308":"J","8196":"u v w x y z QD RD SD KC TD UD VD WD XD 9B AC BC YD"},Q:{"8196":"ZD"},R:{"8196":"aD"},S:{"4100":"bD cD"}},B:5,C:"Synchronous Clipboard API",D:true};
