module.exports={A:{A:{"1":"A B","2":"K D E F aC"},B:{"1":"C L M G N O P","516":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I"},C:{"132":"gB hB iB jB kB lB mB DC nB EC oB pB qB","164":"bC CC J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB dC eC","516":"rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a","1028":"0 1 2 3 4 5 6 7 8 9 b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC"},D:{"420":"J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB","516":"0 1 2 3 4 5 6 7 8 9 eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC"},E:{"1":"A B C L M G KC 6B 7B kC lC mC LC MC 8B nC 9B NC OC PC QC RC oC AC SC TC UC VC WC XC BC pC","132":"F jC","164":"D E iC","420":"J EB K fC JC gC hC"},F:{"1":"C 6B YC uC 7B","2":"F B qC rC sC tC","420":"G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB","516":"RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t"},G:{"1":"2C 3C 4C 5C 6C 7C 8C 9C AD BD CD DD ED LC MC 8B FD 9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC","132":"0C 1C","164":"E yC zC","420":"JC vC ZC wC xC"},H:{"1":"HD"},I:{"420":"CC J ID JD KD LD ZC MD ND","516":"I"},J:{"420":"D A"},K:{"1":"C 6B YC 7B","2":"A B","516":"H"},L:{"516":"I"},M:{"1028":"5B"},N:{"1":"A B"},O:{"516":"8B"},P:{"420":"J","516":"u v w x y z OD PD QD RD SD KC TD UD VD WD XD 9B AC BC YD"},Q:{"516":"ZD"},R:{"516":"aD"},S:{"164":"bD cD"}},B:4,C:"CSS3 Multiple column layout",D:true};
