module.exports={A:{A:{"2":"K D E F A B aC"},B:{"1":"0 1 2 3 4 5 6 7 8 9 Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I","2":"C L M G N O P","1028":"W X","1540":"Q H R S T U V"},C:{"1":"0 1 2 3 4 5 6 7 8 9 sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC","2":"bC","164":"CC J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB dC eC","1540":"VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC","292":"J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB","1028":"W X","1540":"vB wB xB yB zB 0B 1B 2B 3B 4B Q H R S T U V"},E:{"1":"G mC LC MC 8B nC 9B NC OC PC QC RC oC AC SC TC UC VC WC XC BC pC","292":"J EB K D E F A B C fC JC gC hC iC jC KC 6B","1540":"L M 7B kC","3076":"lC"},F:{"1":"2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t","2":"F B C qC rC sC tC 6B YC uC 7B","292":"G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB","1028":"0B 1B","1540":"kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB"},G:{"1":"ED LC MC 8B FD 9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC","292":"E JC vC ZC wC xC yC zC 0C 1C 2C 3C 4C 5C 6C","1540":"7C 8C 9C AD BD CD","3076":"DD"},H:{"2":"HD"},I:{"1":"I","292":"CC J ID JD KD LD ZC MD ND"},J:{"292":"D A"},K:{"1":"H","2":"A B C 6B YC 7B"},L:{"1":"I"},M:{"1":"5B"},N:{"2":"A B"},O:{"1":"8B"},P:{"1":"u v w x y z XD 9B AC BC YD","292":"J OD PD QD RD SD","1540":"KC TD UD VD WD"},Q:{"1540":"ZD"},R:{"1":"aD"},S:{"1":"cD","1540":"bD"}},B:5,C:"CSS Logical Properties",D:true};
