module.exports={A:{A:{"2":"K aC","2340":"D E F A B"},B:{"2":"C L M G N O P","1025":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I"},C:{"1":"0 1 2 3 4 5 6 7 8 9 c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC","2":"bC CC dC","513":"rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b","545":"J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB eC"},D:{"2":"J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB","1025":"0 1 2 3 4 5 6 7 8 9 VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC"},E:{"1":"A B C L M G KC 6B 7B kC lC mC LC MC 8B nC 9B NC OC PC QC RC oC AC SC TC UC VC WC XC BC pC","2":"J EB fC JC gC","164":"K","4644":"D E F hC iC jC"},F:{"2":"F B G N O P FB u v w x y z GB HB qC rC sC tC 6B YC","545":"C uC 7B","1025":"IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t"},G:{"1":"2C 3C 4C 5C 6C 7C 8C 9C AD BD CD DD ED LC MC 8B FD 9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC","2":"JC vC ZC","4260":"wC xC","4644":"E yC zC 0C 1C"},H:{"2":"HD"},I:{"2":"CC J ID JD KD LD ZC MD ND","1025":"I"},J:{"2":"D","4260":"A"},K:{"2":"A B 6B YC","545":"C 7B","1025":"H"},L:{"1025":"I"},M:{"1":"5B"},N:{"2340":"A B"},O:{"1025":"8B"},P:{"1025":"J u v w x y z OD PD QD RD SD KC TD UD VD WD XD 9B AC BC YD"},Q:{"1025":"ZD"},R:{"1025":"aD"},S:{"1":"cD","4097":"bD"}},B:4,C:"Crisp edges/pixelated images",D:true};
