module.exports={A:{D:{"1":"0 1 2 3 4 5 6 7 8 9 cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC","2":"J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB"},L:{"1":"I"},B:{"1":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I","2":"C L M G N O P"},C:{"1":"0 1 2 3 4 5 6 7 8 9 eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC","2":"bC CC J EB K D E F dC eC","33":"A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB"},M:{"1":"5B"},A:{"2":"K D E F A B aC"},F:{"1":"PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t","2":"F B C G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB qC rC sC tC 6B YC uC 7B"},K:{"1":"H","2":"A B C 6B YC 7B"},E:{"1":"B C L M G 6B 7B kC lC mC LC MC 8B nC 9B NC OC PC QC RC oC AC SC TC UC VC WC XC BC","2":"J EB fC JC gC pC","33":"K D E F A hC iC jC KC"},G:{"1":"4C 5C 6C 7C 8C 9C AD BD CD DD ED LC MC 8B FD 9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC","2":"JC vC ZC wC","33":"E xC yC zC 0C 1C 2C 3C"},P:{"1":"u v w x y z OD PD QD RD SD KC TD UD VD WD XD 9B AC BC YD","2":"J"},I:{"1":"I","2":"CC J ID JD KD LD ZC MD ND"}},B:6,C:"plaintext from unicode-bidi",D:undefined};
