import { Command, Diagnostic, TextEdit } from 'vscode-languageserver-types';
export declare class DockerCommands {
    analyzeDiagnostics(diagnostics: Diagnostic[], textDocumentURI: string): Command[];
    computeCommandEdits(content: string, command: string, args: any[]): TextEdit[];
}
