module.exports={A:{A:{"2":"K D E aC","132":"F A B"},B:{"1":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I","1028":"C L M G N O P"},C:{"1":"0 1 2 3 4 5 6 7 8 9 oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC","2":"bC CC","260":"J EB K D E F A B C L M G dC eC","1028":"N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC"},D:{"1":"0 1 2 3 4 5 6 7 8 9 uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC","548":"J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB","1028":"JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB"},E:{"1":"9B NC OC PC QC RC oC AC SC TC UC VC WC XC BC pC","2":"fC JC","548":"J EB K D E F A B C L M G gC hC iC jC KC 6B 7B kC lC mC LC MC 8B nC"},F:{"1":"jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t 7B","2":"F","548":"B C qC rC sC tC 6B YC uC","1028":"G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB"},G:{"1":"9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC","16":"JC","548":"E vC ZC wC xC yC zC 0C 1C 2C 3C 4C 5C 6C 7C 8C 9C AD BD CD DD ED LC MC 8B FD"},H:{"132":"HD"},I:{"1":"I","16":"ID JD","548":"CC J KD LD ZC","1028":"MD ND"},J:{"548":"D A"},K:{"1":"H 7B","548":"A B C 6B YC"},L:{"1":"I"},M:{"1":"5B"},N:{"132":"A B"},O:{"1":"8B"},P:{"1":"u v w x y z KC TD UD VD WD XD 9B AC BC YD","1028":"J OD PD QD RD SD"},Q:{"1":"ZD"},R:{"1":"aD"},S:{"1":"bD cD"}},B:4,C:"Media Queries: resolution feature",D:true};
