module.exports={A:{A:{"2":"K D E aC","260":"F A B"},B:{"132":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I","260":"C L M G N O P"},C:{"2":"bC CC J EB dC eC","260":"0 1 2 3 4 5 6 7 8 9 K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC"},D:{"16":"J EB K D E F A B C L M","132":"0 1 2 3 4 5 6 7 8 9 G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC"},E:{"16":"fC JC","132":"J EB K D E F A B C L M G gC hC iC jC KC 6B 7B kC lC mC LC MC 8B nC 9B NC OC PC QC RC oC AC SC TC UC VC WC XC BC pC"},F:{"1":"C uC 7B","2":"F qC rC sC tC","16":"B 6B YC","132":"G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t"},G:{"16":"JC vC","132":"E ZC wC xC yC zC 0C 1C 2C 3C 4C 5C 6C 7C 8C 9C AD BD CD DD ED LC MC 8B FD 9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC"},H:{"2":"HD"},I:{"16":"ID JD","132":"CC J I KD LD ZC MD ND"},J:{"132":"D A"},K:{"1":"C 7B","2":"A","16":"B 6B YC","132":"H"},L:{"132":"I"},M:{"260":"5B"},N:{"260":"A B"},O:{"132":"8B"},P:{"132":"J u v w x y z OD PD QD RD SD KC TD UD VD WD XD 9B AC BC YD"},Q:{"132":"ZD"},R:{"132":"aD"},S:{"260":"bD cD"}},B:5,C:"Mutation events",D:true};
