module.exports={A:{A:{"2":"F A B aC","8":"K D E"},B:{"2":"C L M G N O P","8":"Q H R S T U V W X Y Z a b c d e f","584":"g h i j k l m n o p q r","1025":"0 1 2 3 4 5 6 7 8 9 s t AB BB CB DB I"},C:{"1":"0 1 2 3 4 5 6 7 8 9 J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC","129":"bC CC dC eC"},D:{"1":"y","8":"J EB K D E F A B C L M G N O P FB u v w x z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R S T U V W X Y Z a b c d e f","584":"g h i j k l m n o p q r","1025":"0 1 2 3 4 5 6 7 8 9 s t AB BB CB DB I 5B GC HC IC"},E:{"1":"A B C L M G KC 6B 7B kC lC mC LC MC 8B nC 9B NC OC PC QC RC oC AC SC TC UC VC WC XC BC pC","260":"J EB K D E F fC JC gC hC iC jC"},F:{"2":"F","8":"G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC","584":"S T U V W X Y Z a b c d","1025":"e f g h i j k l m n o p q r s t","2052":"B C qC rC sC tC 6B YC uC 7B"},G:{"1":"E wC xC yC zC 0C 1C 2C 3C 4C 5C 6C 7C 8C 9C AD BD CD DD ED LC MC 8B FD 9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC","8":"JC vC ZC"},H:{"8":"HD"},I:{"8":"CC J ID JD KD LD ZC MD ND","1025":"I"},J:{"1":"A","8":"D"},K:{"8":"A B C 6B YC 7B","1025":"H"},L:{"1025":"I"},M:{"1":"5B"},N:{"2":"A B"},O:{"8":"8B"},P:{"1":"v w x y z","8":"J u OD PD QD RD SD KC TD UD VD WD XD 9B AC BC YD"},Q:{"8":"ZD"},R:{"8":"aD"},S:{"1":"bD cD"}},B:2,C:"MathML",D:true};
