module.exports={A:{A:{"1":"B","2":"K D E F A aC"},B:{"2":"0 1 2 3 4 5 6 7 8 9 C L M G N O P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I"},C:{"1":"L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB","2":"0 1 2 3 4 5 6 7 8 9 bC CC J EB K D E F A B C fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC dC eC"},D:{"1":"J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB","2":"0 1 2 3 4 5 6 7 8 9 fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC"},E:{"1":"E F A B C jC KC 6B","2":"J EB K D fC JC gC hC iC","129":"L M G 7B kC lC mC LC MC 8B nC 9B NC OC PC QC RC oC AC SC TC UC VC WC XC BC pC"},F:{"1":"G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB WB YB 7B","2":"F B C UB VB XB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t qC rC sC tC 6B YC uC"},G:{"1":"E zC 0C 1C 2C 3C 4C 5C 6C","2":"JC vC ZC wC xC yC","257":"7C 8C 9C AD BD CD DD ED LC MC 8B FD 9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC"},H:{"2":"HD"},I:{"1":"CC J LD ZC MD ND","2":"I ID JD KD"},J:{"2":"D A"},K:{"1":"7B","2":"A B C H 6B YC"},L:{"2":"I"},M:{"2":"5B"},N:{"1":"B","2":"A"},O:{"2":"8B"},P:{"1":"J","2":"u v w x y z OD PD QD RD SD KC TD UD VD WD XD 9B AC BC YD"},Q:{"2":"ZD"},R:{"2":"aD"},S:{"1":"bD","2":"cD"}},B:7,C:"SPDY protocol",D:true};
