import { FoldingRange } from 'vscode-languageserver-types';
export declare class DockerFolding {
    private createFoldingRange;
    private getLineLength;
    computeFoldingRanges(content: string, lineFoldingOnly: boolean, limit: number): FoldingRange[];
}
