import { Position, Range, Location, TextDocumentIdentifier } from 'vscode-languageserver-types';
import { Dockerfile, Property } from 'dockerfile-ast';
export declare class DockerDefinition {
    private computeBuildStageDefinition;
    private static computeVariableDefinition;
    static findDefinition(dockerfile: Dockerfile, position: Position): Property;
    private static checkHeredocs;
    private static computeHeredocDefinition;
    private computeVariableDefinition;
    computeDefinitionRange(content: string, position: Position): Range | null;
    computeDefinition(textDocument: TextDocumentIdentifier, content: string, position: Position): Location | null;
}
