module.exports={A:{A:{"2":"K D E F A B aC"},B:{"1":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I","2":"C","260":"L M G N O P"},C:{"1":"0 1 2 3 4 5 6 7 8 9 eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC","2":"bC CC J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB dC eC","516":"JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC","2":"J","16":"EB K D E F A B C L M","260":"gB","772":"G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB"},E:{"1":"B C L M G KC 6B 7B kC lC mC LC MC 8B nC 9B NC OC PC QC RC oC AC SC TC UC VC WC XC BC pC","2":"J fC JC","16":"EB","772":"K D E F A gC hC iC jC"},F:{"1":"UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t","16":"F qC","260":"B C TB rC sC tC 6B YC uC 7B","772":"G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB"},G:{"1":"3C 4C 5C 6C 7C 8C 9C AD BD CD DD ED LC MC 8B FD 9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC","2":"JC vC ZC","772":"E wC xC yC zC 0C 1C 2C"},H:{"132":"HD"},I:{"1":"I","2":"CC ID JD KD","260":"J LD ZC MD ND"},J:{"2":"D","260":"A"},K:{"1":"H","260":"A B C 6B YC 7B"},L:{"1":"I"},M:{"1":"5B"},N:{"2":"A B"},O:{"1":"8B"},P:{"1":"u v w x y z OD PD QD RD SD KC TD UD VD WD XD 9B AC BC YD","260":"J"},Q:{"1":"ZD"},R:{"1":"aD"},S:{"1":"cD","516":"bD"}},B:5,C:":in-range and :out-of-range CSS pseudo-classes",D:true};
