module.exports={A:{A:{"2":"K D E F A B aC"},B:{"2":"C L M G N O P","1025":"0 1 2 3 4 5 6 7 8 9 d e f g h i j k l m n o p q r s t AB BB CB DB I","1537":"Q H R S T U V W X Y Z a b c"},C:{"2":"bC","932":"CC J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB dC eC","2308":"0 1 2 3 4 5 6 7 8 9 sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC"},D:{"2":"J EB K D E F A B C L M G N O P FB u v","545":"w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB","1025":"0 1 2 3 4 5 6 7 8 9 d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC","1537":"aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R S T U V W X Y Z a b c"},E:{"1":"9B NC OC PC QC RC oC AC SC TC UC VC WC XC BC pC","2":"J EB K fC JC gC","516":"B C L M G 6B 7B kC lC mC LC MC 8B nC","548":"F A jC KC","676":"D E hC iC"},F:{"2":"F B C qC rC sC tC 6B YC uC 7B","513":"OB","545":"G N O P FB u v w x y z GB HB IB JB KB LB MB","1025":"e f g h i j k l m n o p q r s t","1537":"NB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d"},G:{"1":"9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC","2":"JC vC ZC wC xC","516":"CD DD ED LC MC 8B FD","548":"0C 1C 2C 3C 4C 5C 6C 7C 8C 9C AD BD","676":"E yC zC"},H:{"2":"HD"},I:{"2":"CC J ID JD KD LD ZC","545":"MD ND","1025":"I"},J:{"2":"D","545":"A"},K:{"2":"A B C 6B YC 7B","1025":"H"},L:{"1025":"I"},M:{"2308":"5B"},N:{"2":"A B"},O:{"1537":"8B"},P:{"545":"J","1025":"u v w x y z AC BC YD","1537":"OD PD QD RD SD KC TD UD VD WD XD 9B"},Q:{"1537":"ZD"},R:{"1537":"aD"},S:{"932":"bD","2308":"cD"}},B:5,C:"Intrinsic & Extrinsic Sizing",D:true};
