module.exports={A:{A:{"2":"K D E F A aC","132":"B"},B:{"1":"C L M G N O P","4":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I"},C:{"2":"bC CC dC","4":"0 1 2 3 4 5 6 7 8 9 K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC","8":"J EB eC"},D:{"2":"J EB K","4":"0 1 2 3 4 5 6 7 8 9 D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC"},E:{"2":"J EB K D E F A B C L M G fC JC gC hC iC jC KC 6B 7B kC lC mC LC MC 8B nC 9B NC OC PC QC RC oC AC SC TC UC VC WC XC BC pC"},F:{"2":"F B C qC rC sC tC 6B YC uC 7B","4":"G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t"},G:{"2":"JC vC","4":"E ZC wC xC yC zC 0C 1C 2C 3C 4C 5C 6C 7C 8C 9C AD BD CD DD ED LC MC 8B FD 9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC"},H:{"2":"HD"},I:{"2":"ID JD KD","4":"CC J I LD ZC MD ND"},J:{"2":"D","4":"A"},K:{"1":"C 7B","2":"A B 6B YC","4":"H"},L:{"4":"I"},M:{"4":"5B"},N:{"1":"B","2":"A"},O:{"4":"8B"},P:{"4":"J u v w x y z OD PD QD RD SD KC TD UD VD WD XD 9B AC BC YD"},Q:{"4":"ZD"},R:{"4":"aD"},S:{"4":"bD cD"}},B:4,C:"DeviceOrientation & DeviceMotion events",D:true};
