module.exports={A:{A:{"2":"K D E F A aC","548":"B"},B:{"1":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I","516":"C L M G N O P"},C:{"1":"0 1 2 3 4 5 6 7 8 9 qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC","2":"bC CC J EB K D E F dC eC","676":"A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB","1700":"bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 xB yB zB 0B 1B 2B 3B 4B Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC","2":"J EB K D E F A B C L M","676":"G N O P FB","804":"u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB"},E:{"1":"QC RC oC AC SC TC UC VC WC XC BC pC","2":"J EB fC JC","548":"MC 8B nC 9B NC OC PC","676":"gC","804":"K D E F A B C L M G hC iC jC KC 6B 7B kC lC mC LC"},F:{"1":"qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t 7B","2":"F B C qC rC sC tC 6B YC uC","804":"G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB"},G:{"2":"E JC vC ZC wC xC yC zC 0C 1C 2C 3C 4C 5C","2052":"6C 7C 8C 9C AD BD CD DD ED LC MC 8B FD 9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC"},H:{"2":"HD"},I:{"2":"CC J I ID JD KD LD ZC MD ND"},J:{"2":"D","292":"A"},K:{"1":"H","2":"A B C 6B YC 7B"},L:{"1":"I"},M:{"1":"5B"},N:{"2":"A","548":"B"},O:{"1":"8B"},P:{"1":"u v w x y z KC TD UD VD WD XD 9B AC BC YD","804":"J OD PD QD RD SD"},Q:{"1":"ZD"},R:{"1":"aD"},S:{"1":"bD cD"}},B:1,C:"Fullscreen API",D:true};
