import { Position, SignatureHelp } from 'vscode-languageserver-types';
export declare class DockerSignatures {
    private documentation;
    computeSignatures(content: string, position: Position): SignatureHelp;
    private getInstructionSignatures;
    private getFromSignatureHelp;
    private getFromSignatures;
    private getFromActiveParameter;
    private getJSONInstructionSignatureHelp;
    private getJSONSignatureActiveParameter;
    private getSignatureActiveParameter;
    private getPropertySignatureHelp;
    private getPropertySignatures;
    private getPropertySignatureActiveParameter;
    private static isInName;
    private static isNameBefore;
    private static isInValue;
    private static isValueBefore;
}
