module.exports={A:{A:{"2":"K D E F A B aC"},B:{"2":"C L M G N O P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s","260":"0 1 2 3 4 5 6 7 8 9 t AB BB CB DB I"},C:{"2":"0 1 2 3 4 5 6 7 8 9 bC CC J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t AB BB CB DB I 5B GC HC IC cC dC eC"},D:{"2":"J EB K D E F A B C L M G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB DC nB EC oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s","260":"0 1 2 3 4 5 6 7 8 9 t AB BB CB DB I 5B GC HC IC"},E:{"2":"J EB K D E fC JC gC hC iC","260":"F","420":"A B C L M G jC KC 6B 7B kC lC mC LC MC 8B nC 9B NC OC PC QC RC oC AC SC TC UC VC WC XC BC pC"},F:{"2":"F B C G N O P FB u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B Q H R FC S T U V W X Y Z a b c d e f g qC rC sC tC 6B YC uC 7B","260":"h i j k l m n o p q r s t"},G:{"2":"E JC vC ZC wC xC yC zC","420":"0C 1C 2C 3C 4C 5C 6C 7C 8C 9C AD BD CD DD ED LC MC 8B FD 9B NC OC PC QC RC GD AC SC TC UC VC WC XC BC"},H:{"2":"HD"},I:{"2":"CC J ID JD KD LD ZC MD ND","260":"I"},J:{"2":"D A"},K:{"2":"A B C 6B YC 7B","260":"H"},L:{"260":"I"},M:{"2":"5B"},N:{"2":"A B"},O:{"2":"8B"},P:{"2":"J u OD PD QD RD SD KC TD UD VD WD XD 9B AC BC YD","260":"v w x y z"},Q:{"2":"ZD"},R:{"2":"aD"},S:{"2":"bD cD"}},B:5,C:"CSS Initial Letter",D:true};
